.. _recipes:

=================
Available recipes
=================

.. contents::
   :local:

.. toctree::
   :maxdepth: 1

   recipe_asr.bader.rst
   recipe_asr.bandstructure.rst
   recipe_asr.berry.rst
   recipe_asr.borncharges.rst
   recipe_asr.bse.rst
   recipe_asr.chc.rst
   recipe_asr.convex_hull.rst
   recipe_asr.defectformation.rst
   recipe_asr.deformationpotentials.rst
   recipe_asr.dimensionality.rst
   recipe_asr.dos.rst
   recipe_asr.emasses.rst
   recipe_asr.exchange.rst
   recipe_asr.fere.rst
   recipe_asr.fermisurface.rst
   recipe_asr.formalpolarization.rst
   recipe_asr.gs.rst
   recipe_asr.gw.rst
   recipe_asr.hse.rst
   recipe_asr.infraredpolarizability.rst
   recipe_asr.magnetic_anisotropy.rst
   recipe_asr.magstate.rst
   recipe_asr.pdos.rst
   recipe_asr.phonons.rst
   recipe_asr.phonopy.rst
   recipe_asr.piezoelectrictensor.rst
   recipe_asr.plasmafrequency.rst
   recipe_asr.polarizability.rst
   recipe_asr.projected_bandstructure.rst
   recipe_asr.push.rst
   recipe_asr.raman.rst
   recipe_asr.relax.rst
   recipe_asr.setinfo.rst
   recipe_asr.setup.decorate.rst
   recipe_asr.setup.defects.rst
   recipe_asr.setup.displacements.rst
   recipe_asr.setup.magnetize.rst
   recipe_asr.setup.materials.rst
   recipe_asr.setup.params.rst
   recipe_asr.setup.scanparams.rst
   recipe_asr.setup.strains.rst
   recipe_asr.setup.symmetrize.rst
   recipe_asr.stiffness.rst
   recipe_asr.structureinfo.rst
   recipe_asr.workflow.rst